====================================
ScrapyDD (Scrapy Distributed Daemon)
====================================

.. image:: https://img.shields.io/pypi/v/scrapydd.svg
   :target: https://pypi.python.org/pypi/scrapydd
   :alt: PyPI Version

.. image:: https://img.shields.io/travis/kevenli/scrapydd/master.svg
   :target: http://travis-ci.org/kevenli/scrapydd
   :alt: Build Status

.. image:: https://img.shields.io/codecov/c/github/kevenli/scrapydd/master.svg
   :target: http://codecov.io/gh/kevenli/scrapydd?branch=master
   :alt: Coverage report


Scrapydd is a system for scrapy spiders distributed running and scheduleing system, including server and client agent.


Installing Scrapydd
-------------------
By pip::

    pip install scrapydd

You can also install scrapydd manually:

1. Download compressed package from `github releases`_.
2. Decompress the package
3. Run ``python setup.py install``


Docs
----
The docs is hosted `here`_


.. _here: http://scrapydd.readthedocs.org
